import { AxiosRequestConfig, AxiosError, AxiosResponse } from 'axios';

type ParamValue<T> = T extends (`id` | `${string}Id`) ? number : string

type PartialRightUrl<T> = T extends `:${infer Center}/${infer Right}`
    ? Center | PartialRightUrl<Right>
    : (T extends `:${infer Right}` ? Right : never)
type PartialLeftUrl<T> = T extends `${infer Left}/${infer Right}` ? Left | PartialRightUrl<Right> : T

type ParamNames<Url> = Url extends (`${infer PartLeft}/:${infer PartRight}` | `[${string}]${infer PartLeft}/:${infer PartRight}`)
    ? PartialLeftUrl<PartRight> : never


type StrictParamObject<Url> = {
    [key in ParamNames<Url>]: ParamValue<key>
}

type ParamObject<Url> = { [key: string]: any } | StrictParamObject<Url>
type ApiHandler<Url> = (data?: ParamObject<Url>, requestConfig?: ReqCfg) => Promise<any>

type Transform<Urls> = {
    [Key in keyof Urls]: ApiHandler<Urls[Key]>
}

type handleError = (value?: AxiosError) => any;
type handleResponse = (value?: AxiosResponse) => any;
type Domain = Object | String | Function


interface Options {
    handleError?: handleError
    handleResponse?: handleResponse
    requestMethods?: Object
    domain?: Domain,
    axiosConfig?: AxiosRequestConfig
}

declare class ApiPlus {
    options: Options;
    constructor(options?: Options);
    transform<T>(requestUrlMap: T): Transform<T>;
}

export { ApiPlus as default };
//# sourceMappingURL=index.d.ts.map
